(**************************************************************************)
(*                Lablgtk                                                 *)
(*                                                                        *)
(*    This program is free software; you can redistribute it              *)
(*    and/or modify it under the terms of the GNU Library General         *)
(*    Public License as published by the Free Software Foundation         *)
(*    version 2, with the exception described in file COPYING which       *)
(*    comes with the library.                                             *)
(*                                                                        *)
(*    This program is distributed in the hope that it will be useful,     *)
(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
(*    GNU Library General Public License for more details.                *)
(*                                                                        *)
(*    You should have received a copy of the GNU Library General          *)
(*    Public License along with this program; if not, write to the        *)
(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
(*    Boston, MA 02111-1307  USA                                          *)
(*                                                                        *)
(*                                                                        *)
(**************************************************************************)

(* $Id$ *)

open Gdk
let _VoidSymbol : keysym = 0xFFFFFF
let _BackSpace : keysym = 0xFF08
let _Tab : keysym = 0xFF09
let _Linefeed : keysym = 0xFF0A
let _Clear : keysym = 0xFF0B
let _Return : keysym = 0xFF0D
let _Pause : keysym = 0xFF13
let _Scroll_Lock : keysym = 0xFF14
let _Sys_Req : keysym = 0xFF15
let _Escape : keysym = 0xFF1B
let _Delete : keysym = 0xFFFF
let _Multi_key : keysym = 0xFF20
let _SingleCandidate : keysym = 0xFF3C
let _MultipleCandidate : keysym = 0xFF3D
let _PreviousCandidate : keysym = 0xFF3E
let _Kanji : keysym = 0xFF21
let _Muhenkan : keysym = 0xFF22
let _Henkan_Mode : keysym = 0xFF23
let _Henkan : keysym = 0xFF23
let _Romaji : keysym = 0xFF24
let _Hiragana : keysym = 0xFF25
let _Katakana : keysym = 0xFF26
let _Hiragana_Katakana : keysym = 0xFF27
let _Zenkaku : keysym = 0xFF28
let _Hankaku : keysym = 0xFF29
let _Zenkaku_Hankaku : keysym = 0xFF2A
let _Touroku : keysym = 0xFF2B
let _Massyo : keysym = 0xFF2C
let _Kana_Lock : keysym = 0xFF2D
let _Kana_Shift : keysym = 0xFF2E
let _Eisu_Shift : keysym = 0xFF2F
let _Eisu_toggle : keysym = 0xFF30
let _Zen_Koho : keysym = 0xFF3D
let _Mae_Koho : keysym = 0xFF3E
let _Home : keysym = 0xFF50
let _Left : keysym = 0xFF51
let _Up : keysym = 0xFF52
let _Right : keysym = 0xFF53
let _Down : keysym = 0xFF54
let _Prior : keysym = 0xFF55
let _Page_Up : keysym = 0xFF55
let _Next : keysym = 0xFF56
let _Page_Down : keysym = 0xFF56
let _End : keysym = 0xFF57
let _Begin : keysym = 0xFF58
let _Select : keysym = 0xFF60
let _Print : keysym = 0xFF61
let _Execute : keysym = 0xFF62
let _Insert : keysym = 0xFF63
let _Undo : keysym = 0xFF65
let _Redo : keysym = 0xFF66
let _Menu : keysym = 0xFF67
let _Find : keysym = 0xFF68
let _Cancel : keysym = 0xFF69
let _Help : keysym = 0xFF6A
let _Break : keysym = 0xFF6B
let _Mode_switch : keysym = 0xFF7E
let _script_switch : keysym = 0xFF7E
let _Num_Lock : keysym = 0xFF7F
let _KP_Space : keysym = 0xFF80
let _KP_Tab : keysym = 0xFF89
let _KP_Enter : keysym = 0xFF8D
let _KP_F1 : keysym = 0xFF91
let _KP_F2 : keysym = 0xFF92
let _KP_F3 : keysym = 0xFF93
let _KP_F4 : keysym = 0xFF94
let _KP_Home : keysym = 0xFF95
let _KP_Left : keysym = 0xFF96
let _KP_Up : keysym = 0xFF97
let _KP_Right : keysym = 0xFF98
let _KP_Down : keysym = 0xFF99
let _KP_Prior : keysym = 0xFF9A
let _KP_Page_Up : keysym = 0xFF9A
let _KP_Next : keysym = 0xFF9B
let _KP_Page_Down : keysym = 0xFF9B
let _KP_End : keysym = 0xFF9C
let _KP_Begin : keysym = 0xFF9D
let _KP_Insert : keysym = 0xFF9E
let _KP_Delete : keysym = 0xFF9F
let _KP_Equal : keysym = 0xFFBD
let _KP_Multiply : keysym = 0xFFAA
let _KP_Add : keysym = 0xFFAB
let _KP_Separator : keysym = 0xFFAC
let _KP_Subtract : keysym = 0xFFAD
let _KP_Decimal : keysym = 0xFFAE
let _KP_Divide : keysym = 0xFFAF
let _KP_0 : keysym = 0xFFB0
let _KP_1 : keysym = 0xFFB1
let _KP_2 : keysym = 0xFFB2
let _KP_3 : keysym = 0xFFB3
let _KP_4 : keysym = 0xFFB4
let _KP_5 : keysym = 0xFFB5
let _KP_6 : keysym = 0xFFB6
let _KP_7 : keysym = 0xFFB7
let _KP_8 : keysym = 0xFFB8
let _KP_9 : keysym = 0xFFB9
let _F1 : keysym = 0xFFBE
let _F2 : keysym = 0xFFBF
let _F3 : keysym = 0xFFC0
let _F4 : keysym = 0xFFC1
let _F5 : keysym = 0xFFC2
let _F6 : keysym = 0xFFC3
let _F7 : keysym = 0xFFC4
let _F8 : keysym = 0xFFC5
let _F9 : keysym = 0xFFC6
let _F10 : keysym = 0xFFC7
let _F11 : keysym = 0xFFC8
let _L1 : keysym = 0xFFC8
let _F12 : keysym = 0xFFC9
let _L2 : keysym = 0xFFC9
let _F13 : keysym = 0xFFCA
let _L3 : keysym = 0xFFCA
let _F14 : keysym = 0xFFCB
let _L4 : keysym = 0xFFCB
let _F15 : keysym = 0xFFCC
let _L5 : keysym = 0xFFCC
let _F16 : keysym = 0xFFCD
let _L6 : keysym = 0xFFCD
let _F17 : keysym = 0xFFCE
let _L7 : keysym = 0xFFCE
let _F18 : keysym = 0xFFCF
let _L8 : keysym = 0xFFCF
let _F19 : keysym = 0xFFD0
let _L9 : keysym = 0xFFD0
let _F20 : keysym = 0xFFD1
let _L10 : keysym = 0xFFD1
let _F21 : keysym = 0xFFD2
let _R1 : keysym = 0xFFD2
let _F22 : keysym = 0xFFD3
let _R2 : keysym = 0xFFD3
let _F23 : keysym = 0xFFD4
let _R3 : keysym = 0xFFD4
let _F24 : keysym = 0xFFD5
let _R4 : keysym = 0xFFD5
let _F25 : keysym = 0xFFD6
let _R5 : keysym = 0xFFD6
let _F26 : keysym = 0xFFD7
let _R6 : keysym = 0xFFD7
let _F27 : keysym = 0xFFD8
let _R7 : keysym = 0xFFD8
let _F28 : keysym = 0xFFD9
let _R8 : keysym = 0xFFD9
let _F29 : keysym = 0xFFDA
let _R9 : keysym = 0xFFDA
let _F30 : keysym = 0xFFDB
let _R10 : keysym = 0xFFDB
let _F31 : keysym = 0xFFDC
let _R11 : keysym = 0xFFDC
let _F32 : keysym = 0xFFDD
let _R12 : keysym = 0xFFDD
let _F33 : keysym = 0xFFDE
let _R13 : keysym = 0xFFDE
let _F34 : keysym = 0xFFDF
let _R14 : keysym = 0xFFDF
let _F35 : keysym = 0xFFE0
let _R15 : keysym = 0xFFE0
let _Shift_L : keysym = 0xFFE1
let _Shift_R : keysym = 0xFFE2
let _Control_L : keysym = 0xFFE3
let _Control_R : keysym = 0xFFE4
let _Caps_Lock : keysym = 0xFFE5
let _Shift_Lock : keysym = 0xFFE6
let _Meta_L : keysym = 0xFFE7
let _Meta_R : keysym = 0xFFE8
let _Alt_L : keysym = 0xFFE9
let _Alt_R : keysym = 0xFFEA
let _Super_L : keysym = 0xFFEB
let _Super_R : keysym = 0xFFEC
let _Hyper_L : keysym = 0xFFED
let _Hyper_R : keysym = 0xFFEE
let _ISO_Lock : keysym = 0xFE01
let _ISO_Level2_Latch : keysym = 0xFE02
let _ISO_Level3_Shift : keysym = 0xFE03
let _ISO_Level3_Latch : keysym = 0xFE04
let _ISO_Level3_Lock : keysym = 0xFE05
let _ISO_Group_Shift : keysym = 0xFF7E
let _ISO_Group_Latch : keysym = 0xFE06
let _ISO_Group_Lock : keysym = 0xFE07
let _ISO_Next_Group : keysym = 0xFE08
let _ISO_Next_Group_Lock : keysym = 0xFE09
let _ISO_Prev_Group : keysym = 0xFE0A
let _ISO_Prev_Group_Lock : keysym = 0xFE0B
let _ISO_First_Group : keysym = 0xFE0C
let _ISO_First_Group_Lock : keysym = 0xFE0D
let _ISO_Last_Group : keysym = 0xFE0E
let _ISO_Last_Group_Lock : keysym = 0xFE0F
let _ISO_Left_Tab : keysym = 0xFE20
let _ISO_Move_Line_Up : keysym = 0xFE21
let _ISO_Move_Line_Down : keysym = 0xFE22
let _ISO_Partial_Line_Up : keysym = 0xFE23
let _ISO_Partial_Line_Down : keysym = 0xFE24
let _ISO_Partial_Space_Left : keysym = 0xFE25
let _ISO_Partial_Space_Right : keysym = 0xFE26
let _ISO_Set_Margin_Left : keysym = 0xFE27
let _ISO_Set_Margin_Right : keysym = 0xFE28
let _ISO_Release_Margin_Left : keysym = 0xFE29
let _ISO_Release_Margin_Right : keysym = 0xFE2A
let _ISO_Release_Both_Margins : keysym = 0xFE2B
let _ISO_Fast_Cursor_Left : keysym = 0xFE2C
let _ISO_Fast_Cursor_Right : keysym = 0xFE2D
let _ISO_Fast_Cursor_Up : keysym = 0xFE2E
let _ISO_Fast_Cursor_Down : keysym = 0xFE2F
let _ISO_Continuous_Underline : keysym = 0xFE30
let _ISO_Discontinuous_Underline : keysym = 0xFE31
let _ISO_Emphasize : keysym = 0xFE32
let _ISO_Center_Object : keysym = 0xFE33
let _ISO_Enter : keysym = 0xFE34
let _dead_grave : keysym = 0xFE50
let _dead_acute : keysym = 0xFE51
let _dead_circumflex : keysym = 0xFE52
let _dead_tilde : keysym = 0xFE53
let _dead_macron : keysym = 0xFE54
let _dead_breve : keysym = 0xFE55
let _dead_abovedot : keysym = 0xFE56
let _dead_diaeresis : keysym = 0xFE57
let _dead_abovering : keysym = 0xFE58
let _dead_doubleacute : keysym = 0xFE59
let _dead_caron : keysym = 0xFE5A
let _dead_cedilla : keysym = 0xFE5B
let _dead_ogonek : keysym = 0xFE5C
let _dead_iota : keysym = 0xFE5D
let _dead_voiced_sound : keysym = 0xFE5E
let _dead_semivoiced_sound : keysym = 0xFE5F
let _dead_belowdot : keysym = 0xFE60
let _First_Virtual_Screen : keysym = 0xFED0
let _Prev_Virtual_Screen : keysym = 0xFED1
let _Next_Virtual_Screen : keysym = 0xFED2
let _Last_Virtual_Screen : keysym = 0xFED4
let _Terminate_Server : keysym = 0xFED5
let _AccessX_Enable : keysym = 0xFE70
let _AccessX_Feedback_Enable : keysym = 0xFE71
let _RepeatKeys_Enable : keysym = 0xFE72
let _SlowKeys_Enable : keysym = 0xFE73
let _BounceKeys_Enable : keysym = 0xFE74
let _StickyKeys_Enable : keysym = 0xFE75
let _MouseKeys_Enable : keysym = 0xFE76
let _MouseKeys_Accel_Enable : keysym = 0xFE77
let _Overlay1_Enable : keysym = 0xFE78
let _Overlay2_Enable : keysym = 0xFE79
let _AudibleBell_Enable : keysym = 0xFE7A
let _Pointer_Left : keysym = 0xFEE0
let _Pointer_Right : keysym = 0xFEE1
let _Pointer_Up : keysym = 0xFEE2
let _Pointer_Down : keysym = 0xFEE3
let _Pointer_UpLeft : keysym = 0xFEE4
let _Pointer_UpRight : keysym = 0xFEE5
let _Pointer_DownLeft : keysym = 0xFEE6
let _Pointer_DownRight : keysym = 0xFEE7
let _Pointer_Button_Dflt : keysym = 0xFEE8
let _Pointer_Button1 : keysym = 0xFEE9
let _Pointer_Button2 : keysym = 0xFEEA
let _Pointer_Button3 : keysym = 0xFEEB
let _Pointer_Button4 : keysym = 0xFEEC
let _Pointer_Button5 : keysym = 0xFEED
let _Pointer_DblClick_Dflt : keysym = 0xFEEE
let _Pointer_DblClick1 : keysym = 0xFEEF
let _Pointer_DblClick2 : keysym = 0xFEF0
let _Pointer_DblClick3 : keysym = 0xFEF1
let _Pointer_DblClick4 : keysym = 0xFEF2
let _Pointer_DblClick5 : keysym = 0xFEF3
let _Pointer_Drag_Dflt : keysym = 0xFEF4
let _Pointer_Drag1 : keysym = 0xFEF5
let _Pointer_Drag2 : keysym = 0xFEF6
let _Pointer_Drag3 : keysym = 0xFEF7
let _Pointer_Drag4 : keysym = 0xFEF8
let _Pointer_Drag5 : keysym = 0xFEFD
let _Pointer_EnableKeys : keysym = 0xFEF9
let _Pointer_Accelerate : keysym = 0xFEFA
let _Pointer_DfltBtnNext : keysym = 0xFEFB
let _Pointer_DfltBtnPrev : keysym = 0xFEFC
let _3270_Duplicate : keysym = 0xFD01
let _3270_FieldMark : keysym = 0xFD02
let _3270_Right2 : keysym = 0xFD03
let _3270_Left2 : keysym = 0xFD04
let _3270_BackTab : keysym = 0xFD05
let _3270_EraseEOF : keysym = 0xFD06
let _3270_EraseInput : keysym = 0xFD07
let _3270_Reset : keysym = 0xFD08
let _3270_Quit : keysym = 0xFD09
let _3270_PA1 : keysym = 0xFD0A
let _3270_PA2 : keysym = 0xFD0B
let _3270_PA3 : keysym = 0xFD0C
let _3270_Test : keysym = 0xFD0D
let _3270_Attn : keysym = 0xFD0E
let _3270_CursorBlink : keysym = 0xFD0F
let _3270_AltCursor : keysym = 0xFD10
let _3270_KeyClick : keysym = 0xFD11
let _3270_Jump : keysym = 0xFD12
let _3270_Ident : keysym = 0xFD13
let _3270_Rule : keysym = 0xFD14
let _3270_Copy : keysym = 0xFD15
let _3270_Play : keysym = 0xFD16
let _3270_Setup : keysym = 0xFD17
let _3270_Record : keysym = 0xFD18
let _3270_ChangeScreen : keysym = 0xFD19
let _3270_DeleteWord : keysym = 0xFD1A
let _3270_ExSelect : keysym = 0xFD1B
let _3270_CursorSelect : keysym = 0xFD1C
let _3270_PrintScreen : keysym = 0xFD1D
let _3270_Enter : keysym = 0xFD1E
let _space : keysym = 0x020
let _exclam : keysym = 0x021
let _quotedbl : keysym = 0x022
let _numbersign : keysym = 0x023
let _dollar : keysym = 0x024
let _percent : keysym = 0x025
let _ampersand : keysym = 0x026
let _apostrophe : keysym = 0x027
let _quoteright : keysym = 0x027
let _parenleft : keysym = 0x028
let _parenright : keysym = 0x029
let _asterisk : keysym = 0x02a
let _plus : keysym = 0x02b
let _comma : keysym = 0x02c
let _minus : keysym = 0x02d
let _period : keysym = 0x02e
let _slash : keysym = 0x02f
let _0 : keysym = 0x030
let _1 : keysym = 0x031
let _2 : keysym = 0x032
let _3 : keysym = 0x033
let _4 : keysym = 0x034
let _5 : keysym = 0x035
let _6 : keysym = 0x036
let _7 : keysym = 0x037
let _8 : keysym = 0x038
let _9 : keysym = 0x039
let _colon : keysym = 0x03a
let _semicolon : keysym = 0x03b
let _less : keysym = 0x03c
let _equal : keysym = 0x03d
let _greater : keysym = 0x03e
let _question : keysym = 0x03f
let _at : keysym = 0x040
let _A : keysym = 0x041
let _B : keysym = 0x042
let _C : keysym = 0x043
let _D : keysym = 0x044
let _E : keysym = 0x045
let _F : keysym = 0x046
let _G : keysym = 0x047
let _H : keysym = 0x048
let _I : keysym = 0x049
let _J : keysym = 0x04a
let _K : keysym = 0x04b
let _L : keysym = 0x04c
let _M : keysym = 0x04d
let _N : keysym = 0x04e
let _O : keysym = 0x04f
let _P : keysym = 0x050
let _Q : keysym = 0x051
let _R : keysym = 0x052
let _S : keysym = 0x053
let _T : keysym = 0x054
let _U : keysym = 0x055
let _V : keysym = 0x056
let _W : keysym = 0x057
let _X : keysym = 0x058
let _Y : keysym = 0x059
let _Z : keysym = 0x05a
let _bracketleft : keysym = 0x05b
let _backslash : keysym = 0x05c
let _bracketright : keysym = 0x05d
let _asciicircum : keysym = 0x05e
let _underscore : keysym = 0x05f
let _grave : keysym = 0x060
let _quoteleft : keysym = 0x060
let _a : keysym = 0x061
let _b : keysym = 0x062
let _c : keysym = 0x063
let _d : keysym = 0x064
let _e : keysym = 0x065
let _f : keysym = 0x066
let _g : keysym = 0x067
let _h : keysym = 0x068
let _i : keysym = 0x069
let _j : keysym = 0x06a
let _k : keysym = 0x06b
let _l : keysym = 0x06c
let _m : keysym = 0x06d
let _n : keysym = 0x06e
let _o : keysym = 0x06f
let _p : keysym = 0x070
let _q : keysym = 0x071
let _r : keysym = 0x072
let _s : keysym = 0x073
let _t : keysym = 0x074
let _u : keysym = 0x075
let _v : keysym = 0x076
let _w : keysym = 0x077
let _x : keysym = 0x078
let _y : keysym = 0x079
let _z : keysym = 0x07a
let _braceleft : keysym = 0x07b
let _bar : keysym = 0x07c
let _braceright : keysym = 0x07d
let _asciitilde : keysym = 0x07e
let _nobreakspace : keysym = 0x0a0
let _exclamdown : keysym = 0x0a1
let _cent : keysym = 0x0a2
let _sterling : keysym = 0x0a3
let _currency : keysym = 0x0a4
let _yen : keysym = 0x0a5
let _brokenbar : keysym = 0x0a6
let _section : keysym = 0x0a7
let _diaeresis : keysym = 0x0a8
let _copyright : keysym = 0x0a9
let _ordfeminine : keysym = 0x0aa
let _guillemotleft : keysym = 0x0ab
let _notsign : keysym = 0x0ac
let _hyphen : keysym = 0x0ad
let _registered : keysym = 0x0ae
let _macron : keysym = 0x0af
let _degree : keysym = 0x0b0
let _plusminus : keysym = 0x0b1
let _twosuperior : keysym = 0x0b2
let _threesuperior : keysym = 0x0b3
let _acute : keysym = 0x0b4
let _mu : keysym = 0x0b5
let _paragraph : keysym = 0x0b6
let _periodcentered : keysym = 0x0b7
let _cedilla : keysym = 0x0b8
let _onesuperior : keysym = 0x0b9
let _masculine : keysym = 0x0ba
let _guillemotright : keysym = 0x0bb
let _onequarter : keysym = 0x0bc
let _onehalf : keysym = 0x0bd
let _threequarters : keysym = 0x0be
let _questiondown : keysym = 0x0bf
let _Agrave : keysym = 0x0c0
let _Aacute : keysym = 0x0c1
let _Acircumflex : keysym = 0x0c2
let _Atilde : keysym = 0x0c3
let _Adiaeresis : keysym = 0x0c4
let _Aring : keysym = 0x0c5
let _AE : keysym = 0x0c6
let _Ccedilla : keysym = 0x0c7
let _Egrave : keysym = 0x0c8
let _Eacute : keysym = 0x0c9
let _Ecircumflex : keysym = 0x0ca
let _Ediaeresis : keysym = 0x0cb
let _Igrave : keysym = 0x0cc
let _Iacute : keysym = 0x0cd
let _Icircumflex : keysym = 0x0ce
let _Idiaeresis : keysym = 0x0cf
let _ETH : keysym = 0x0d0
let _Eth : keysym = 0x0d0
let _Ntilde : keysym = 0x0d1
let _Ograve : keysym = 0x0d2
let _Oacute : keysym = 0x0d3
let _Ocircumflex : keysym = 0x0d4
let _Otilde : keysym = 0x0d5
let _Odiaeresis : keysym = 0x0d6
let _multiply : keysym = 0x0d7
let _Ooblique : keysym = 0x0d8
let _Ugrave : keysym = 0x0d9
let _Uacute : keysym = 0x0da
let _Ucircumflex : keysym = 0x0db
let _Udiaeresis : keysym = 0x0dc
let _Yacute : keysym = 0x0dd
let _THORN : keysym = 0x0de
let _Thorn : keysym = 0x0de
let _ssharp : keysym = 0x0df
let _agrave : keysym = 0x0e0
let _aacute : keysym = 0x0e1
let _acircumflex : keysym = 0x0e2
let _atilde : keysym = 0x0e3
let _adiaeresis : keysym = 0x0e4
let _aring : keysym = 0x0e5
let _ae : keysym = 0x0e6
let _ccedilla : keysym = 0x0e7
let _egrave : keysym = 0x0e8
let _eacute : keysym = 0x0e9
let _ecircumflex : keysym = 0x0ea
let _ediaeresis : keysym = 0x0eb
let _igrave : keysym = 0x0ec
let _iacute : keysym = 0x0ed
let _icircumflex : keysym = 0x0ee
let _idiaeresis : keysym = 0x0ef
let _eth : keysym = 0x0f0
let _ntilde : keysym = 0x0f1
let _ograve : keysym = 0x0f2
let _oacute : keysym = 0x0f3
let _ocircumflex : keysym = 0x0f4
let _otilde : keysym = 0x0f5
let _odiaeresis : keysym = 0x0f6
let _division : keysym = 0x0f7
let _oslash : keysym = 0x0f8
let _ugrave : keysym = 0x0f9
let _uacute : keysym = 0x0fa
let _ucircumflex : keysym = 0x0fb
let _udiaeresis : keysym = 0x0fc
let _yacute : keysym = 0x0fd
let _thorn : keysym = 0x0fe
let _ydiaeresis : keysym = 0x0ff
let _Aogonek : keysym = 0x1a1
let _breve : keysym = 0x1a2
let _Lstroke : keysym = 0x1a3
let _Lcaron : keysym = 0x1a5
let _Sacute : keysym = 0x1a6
let _Scaron : keysym = 0x1a9
let _Scedilla : keysym = 0x1aa
let _Tcaron : keysym = 0x1ab
let _Zacute : keysym = 0x1ac
let _Zcaron : keysym = 0x1ae
let _Zabovedot : keysym = 0x1af
let _aogonek : keysym = 0x1b1
let _ogonek : keysym = 0x1b2
let _lstroke : keysym = 0x1b3
let _lcaron : keysym = 0x1b5
let _sacute : keysym = 0x1b6
let _caron : keysym = 0x1b7
let _scaron : keysym = 0x1b9
let _scedilla : keysym = 0x1ba
let _tcaron : keysym = 0x1bb
let _zacute : keysym = 0x1bc
let _doubleacute : keysym = 0x1bd
let _zcaron : keysym = 0x1be
let _zabovedot : keysym = 0x1bf
let _Racute : keysym = 0x1c0
let _Abreve : keysym = 0x1c3
let _Lacute : keysym = 0x1c5
let _Cacute : keysym = 0x1c6
let _Ccaron : keysym = 0x1c8
let _Eogonek : keysym = 0x1ca
let _Ecaron : keysym = 0x1cc
let _Dcaron : keysym = 0x1cf
let _Dstroke : keysym = 0x1d0
let _Nacute : keysym = 0x1d1
let _Ncaron : keysym = 0x1d2
let _Odoubleacute : keysym = 0x1d5
let _Rcaron : keysym = 0x1d8
let _Uring : keysym = 0x1d9
let _Udoubleacute : keysym = 0x1db
let _Tcedilla : keysym = 0x1de
let _racute : keysym = 0x1e0
let _abreve : keysym = 0x1e3
let _lacute : keysym = 0x1e5
let _cacute : keysym = 0x1e6
let _ccaron : keysym = 0x1e8
let _eogonek : keysym = 0x1ea
let _ecaron : keysym = 0x1ec
let _dcaron : keysym = 0x1ef
let _dstroke : keysym = 0x1f0
let _nacute : keysym = 0x1f1
let _ncaron : keysym = 0x1f2
let _odoubleacute : keysym = 0x1f5
let _udoubleacute : keysym = 0x1fb
let _rcaron : keysym = 0x1f8
let _uring : keysym = 0x1f9
let _tcedilla : keysym = 0x1fe
let _abovedot : keysym = 0x1ff
let _Hstroke : keysym = 0x2a1
let _Hcircumflex : keysym = 0x2a6
let _Iabovedot : keysym = 0x2a9
let _Gbreve : keysym = 0x2ab
let _Jcircumflex : keysym = 0x2ac
let _hstroke : keysym = 0x2b1
let _hcircumflex : keysym = 0x2b6
let _idotless : keysym = 0x2b9
let _gbreve : keysym = 0x2bb
let _jcircumflex : keysym = 0x2bc
let _Cabovedot : keysym = 0x2c5
let _Ccircumflex : keysym = 0x2c6
let _Gabovedot : keysym = 0x2d5
let _Gcircumflex : keysym = 0x2d8
let _Ubreve : keysym = 0x2dd
let _Scircumflex : keysym = 0x2de
let _cabovedot : keysym = 0x2e5
let _ccircumflex : keysym = 0x2e6
let _gabovedot : keysym = 0x2f5
let _gcircumflex : keysym = 0x2f8
let _ubreve : keysym = 0x2fd
let _scircumflex : keysym = 0x2fe
let _kra : keysym = 0x3a2
let _kappa : keysym = 0x3a2
let _Rcedilla : keysym = 0x3a3
let _Itilde : keysym = 0x3a5
let _Lcedilla : keysym = 0x3a6
let _Emacron : keysym = 0x3aa
let _Gcedilla : keysym = 0x3ab
let _Tslash : keysym = 0x3ac
let _rcedilla : keysym = 0x3b3
let _itilde : keysym = 0x3b5
let _lcedilla : keysym = 0x3b6
let _emacron : keysym = 0x3ba
let _gcedilla : keysym = 0x3bb
let _tslash : keysym = 0x3bc
let _ENG : keysym = 0x3bd
let _eng : keysym = 0x3bf
let _Amacron : keysym = 0x3c0
let _Iogonek : keysym = 0x3c7
let _Eabovedot : keysym = 0x3cc
let _Imacron : keysym = 0x3cf
let _Ncedilla : keysym = 0x3d1
let _Omacron : keysym = 0x3d2
let _Kcedilla : keysym = 0x3d3
let _Uogonek : keysym = 0x3d9
let _Utilde : keysym = 0x3dd
let _Umacron : keysym = 0x3de
let _amacron : keysym = 0x3e0
let _iogonek : keysym = 0x3e7
let _eabovedot : keysym = 0x3ec
let _imacron : keysym = 0x3ef
let _ncedilla : keysym = 0x3f1
let _omacron : keysym = 0x3f2
let _kcedilla : keysym = 0x3f3
let _uogonek : keysym = 0x3f9
let _utilde : keysym = 0x3fd
let _umacron : keysym = 0x3fe
let _overline : keysym = 0x47e
let _kana_fullstop : keysym = 0x4a1
let _kana_openingbracket : keysym = 0x4a2
let _kana_closingbracket : keysym = 0x4a3
let _kana_comma : keysym = 0x4a4
let _kana_conjunctive : keysym = 0x4a5
let _kana_middledot : keysym = 0x4a5
let _kana_WO : keysym = 0x4a6
let _kana_a : keysym = 0x4a7
let _kana_i : keysym = 0x4a8
let _kana_u : keysym = 0x4a9
let _kana_e : keysym = 0x4aa
let _kana_o : keysym = 0x4ab
let _kana_ya : keysym = 0x4ac
let _kana_yu : keysym = 0x4ad
let _kana_yo : keysym = 0x4ae
let _kana_tsu : keysym = 0x4af
let _kana_tu : keysym = 0x4af
let _prolongedsound : keysym = 0x4b0
let _kana_A : keysym = 0x4b1
let _kana_I : keysym = 0x4b2
let _kana_U : keysym = 0x4b3
let _kana_E : keysym = 0x4b4
let _kana_O : keysym = 0x4b5
let _kana_KA : keysym = 0x4b6
let _kana_KI : keysym = 0x4b7
let _kana_KU : keysym = 0x4b8
let _kana_KE : keysym = 0x4b9
let _kana_KO : keysym = 0x4ba
let _kana_SA : keysym = 0x4bb
let _kana_SHI : keysym = 0x4bc
let _kana_SU : keysym = 0x4bd
let _kana_SE : keysym = 0x4be
let _kana_SO : keysym = 0x4bf
let _kana_TA : keysym = 0x4c0
let _kana_CHI : keysym = 0x4c1
let _kana_TI : keysym = 0x4c1
let _kana_TSU : keysym = 0x4c2
let _kana_TU : keysym = 0x4c2
let _kana_TE : keysym = 0x4c3
let _kana_TO : keysym = 0x4c4
let _kana_NA : keysym = 0x4c5
let _kana_NI : keysym = 0x4c6
let _kana_NU : keysym = 0x4c7
let _kana_NE : keysym = 0x4c8
let _kana_NO : keysym = 0x4c9
let _kana_HA : keysym = 0x4ca
let _kana_HI : keysym = 0x4cb
let _kana_FU : keysym = 0x4cc
let _kana_HU : keysym = 0x4cc
let _kana_HE : keysym = 0x4cd
let _kana_HO : keysym = 0x4ce
let _kana_MA : keysym = 0x4cf
let _kana_MI : keysym = 0x4d0
let _kana_MU : keysym = 0x4d1
let _kana_ME : keysym = 0x4d2
let _kana_MO : keysym = 0x4d3
let _kana_YA : keysym = 0x4d4
let _kana_YU : keysym = 0x4d5
let _kana_YO : keysym = 0x4d6
let _kana_RA : keysym = 0x4d7
let _kana_RI : keysym = 0x4d8
let _kana_RU : keysym = 0x4d9
let _kana_RE : keysym = 0x4da
let _kana_RO : keysym = 0x4db
let _kana_WA : keysym = 0x4dc
let _kana_N : keysym = 0x4dd
let _voicedsound : keysym = 0x4de
let _semivoicedsound : keysym = 0x4df
let _kana_switch : keysym = 0xFF7E
let _Arabic_comma : keysym = 0x5ac
let _Arabic_semicolon : keysym = 0x5bb
let _Arabic_question_mark : keysym = 0x5bf
let _Arabic_hamza : keysym = 0x5c1
let _Arabic_maddaonalef : keysym = 0x5c2
let _Arabic_hamzaonalef : keysym = 0x5c3
let _Arabic_hamzaonwaw : keysym = 0x5c4
let _Arabic_hamzaunderalef : keysym = 0x5c5
let _Arabic_hamzaonyeh : keysym = 0x5c6
let _Arabic_alef : keysym = 0x5c7
let _Arabic_beh : keysym = 0x5c8
let _Arabic_tehmarbuta : keysym = 0x5c9
let _Arabic_teh : keysym = 0x5ca
let _Arabic_theh : keysym = 0x5cb
let _Arabic_jeem : keysym = 0x5cc
let _Arabic_hah : keysym = 0x5cd
let _Arabic_khah : keysym = 0x5ce
let _Arabic_dal : keysym = 0x5cf
let _Arabic_thal : keysym = 0x5d0
let _Arabic_ra : keysym = 0x5d1
let _Arabic_zain : keysym = 0x5d2
let _Arabic_seen : keysym = 0x5d3
let _Arabic_sheen : keysym = 0x5d4
let _Arabic_sad : keysym = 0x5d5
let _Arabic_dad : keysym = 0x5d6
let _Arabic_tah : keysym = 0x5d7
let _Arabic_zah : keysym = 0x5d8
let _Arabic_ain : keysym = 0x5d9
let _Arabic_ghain : keysym = 0x5da
let _Arabic_tatweel : keysym = 0x5e0
let _Arabic_feh : keysym = 0x5e1
let _Arabic_qaf : keysym = 0x5e2
let _Arabic_kaf : keysym = 0x5e3
let _Arabic_lam : keysym = 0x5e4
let _Arabic_meem : keysym = 0x5e5
let _Arabic_noon : keysym = 0x5e6
let _Arabic_ha : keysym = 0x5e7
let _Arabic_heh : keysym = 0x5e7
let _Arabic_waw : keysym = 0x5e8
let _Arabic_alefmaksura : keysym = 0x5e9
let _Arabic_yeh : keysym = 0x5ea
let _Arabic_fathatan : keysym = 0x5eb
let _Arabic_dammatan : keysym = 0x5ec
let _Arabic_kasratan : keysym = 0x5ed
let _Arabic_fatha : keysym = 0x5ee
let _Arabic_damma : keysym = 0x5ef
let _Arabic_kasra : keysym = 0x5f0
let _Arabic_shadda : keysym = 0x5f1
let _Arabic_sukun : keysym = 0x5f2
let _Arabic_switch : keysym = 0xFF7E
let _Serbian_dje : keysym = 0x6a1
let _Macedonia_gje : keysym = 0x6a2
let _Cyrillic_io : keysym = 0x6a3
let _Ukrainian_ie : keysym = 0x6a4
let _Ukranian_je : keysym = 0x6a4
let _Macedonia_dse : keysym = 0x6a5
let _Ukrainian_i : keysym = 0x6a6
let _Ukranian_i : keysym = 0x6a6
let _Ukrainian_yi : keysym = 0x6a7
let _Ukranian_yi : keysym = 0x6a7
let _Cyrillic_je : keysym = 0x6a8
let _Serbian_je : keysym = 0x6a8
let _Cyrillic_lje : keysym = 0x6a9
let _Serbian_lje : keysym = 0x6a9
let _Cyrillic_nje : keysym = 0x6aa
let _Serbian_nje : keysym = 0x6aa
let _Serbian_tshe : keysym = 0x6ab
let _Macedonia_kje : keysym = 0x6ac
let _Byelorussian_shortu : keysym = 0x6ae
let _Cyrillic_dzhe : keysym = 0x6af
let _Serbian_dze : keysym = 0x6af
let _numerosign : keysym = 0x6b0
let _Serbian_DJE : keysym = 0x6b1
let _Macedonia_GJE : keysym = 0x6b2
let _Cyrillic_IO : keysym = 0x6b3
let _Ukrainian_IE : keysym = 0x6b4
let _Ukranian_JE : keysym = 0x6b4
let _Macedonia_DSE : keysym = 0x6b5
let _Ukrainian_I : keysym = 0x6b6
let _Ukranian_I : keysym = 0x6b6
let _Ukrainian_YI : keysym = 0x6b7
let _Ukranian_YI : keysym = 0x6b7
let _Cyrillic_JE : keysym = 0x6b8
let _Serbian_JE : keysym = 0x6b8
let _Cyrillic_LJE : keysym = 0x6b9
let _Serbian_LJE : keysym = 0x6b9
let _Cyrillic_NJE : keysym = 0x6ba
let _Serbian_NJE : keysym = 0x6ba
let _Serbian_TSHE : keysym = 0x6bb
let _Macedonia_KJE : keysym = 0x6bc
let _Byelorussian_SHORTU : keysym = 0x6be
let _Cyrillic_DZHE : keysym = 0x6bf
let _Serbian_DZE : keysym = 0x6bf
let _Cyrillic_yu : keysym = 0x6c0
let _Cyrillic_a : keysym = 0x6c1
let _Cyrillic_be : keysym = 0x6c2
let _Cyrillic_tse : keysym = 0x6c3
let _Cyrillic_de : keysym = 0x6c4
let _Cyrillic_ie : keysym = 0x6c5
let _Cyrillic_ef : keysym = 0x6c6
let _Cyrillic_ghe : keysym = 0x6c7
let _Cyrillic_ha : keysym = 0x6c8
let _Cyrillic_i : keysym = 0x6c9
let _Cyrillic_shorti : keysym = 0x6ca
let _Cyrillic_ka : keysym = 0x6cb
let _Cyrillic_el : keysym = 0x6cc
let _Cyrillic_em : keysym = 0x6cd
let _Cyrillic_en : keysym = 0x6ce
let _Cyrillic_o : keysym = 0x6cf
let _Cyrillic_pe : keysym = 0x6d0
let _Cyrillic_ya : keysym = 0x6d1
let _Cyrillic_er : keysym = 0x6d2
let _Cyrillic_es : keysym = 0x6d3
let _Cyrillic_te : keysym = 0x6d4
let _Cyrillic_u : keysym = 0x6d5
let _Cyrillic_zhe : keysym = 0x6d6
let _Cyrillic_ve : keysym = 0x6d7
let _Cyrillic_softsign : keysym = 0x6d8
let _Cyrillic_yeru : keysym = 0x6d9
let _Cyrillic_ze : keysym = 0x6da
let _Cyrillic_sha : keysym = 0x6db
let _Cyrillic_e : keysym = 0x6dc
let _Cyrillic_shcha : keysym = 0x6dd
let _Cyrillic_che : keysym = 0x6de
let _Cyrillic_hardsign : keysym = 0x6df
let _Cyrillic_YU : keysym = 0x6e0
let _Cyrillic_A : keysym = 0x6e1
let _Cyrillic_BE : keysym = 0x6e2
let _Cyrillic_TSE : keysym = 0x6e3
let _Cyrillic_DE : keysym = 0x6e4
let _Cyrillic_IE : keysym = 0x6e5
let _Cyrillic_EF : keysym = 0x6e6
let _Cyrillic_GHE : keysym = 0x6e7
let _Cyrillic_HA : keysym = 0x6e8
let _Cyrillic_I : keysym = 0x6e9
let _Cyrillic_SHORTI : keysym = 0x6ea
let _Cyrillic_KA : keysym = 0x6eb
let _Cyrillic_EL : keysym = 0x6ec
let _Cyrillic_EM : keysym = 0x6ed
let _Cyrillic_EN : keysym = 0x6ee
let _Cyrillic_O : keysym = 0x6ef
let _Cyrillic_PE : keysym = 0x6f0
let _Cyrillic_YA : keysym = 0x6f1
let _Cyrillic_ER : keysym = 0x6f2
let _Cyrillic_ES : keysym = 0x6f3
let _Cyrillic_TE : keysym = 0x6f4
let _Cyrillic_U : keysym = 0x6f5
let _Cyrillic_ZHE : keysym = 0x6f6
let _Cyrillic_VE : keysym = 0x6f7
let _Cyrillic_SOFTSIGN : keysym = 0x6f8
let _Cyrillic_YERU : keysym = 0x6f9
let _Cyrillic_ZE : keysym = 0x6fa
let _Cyrillic_SHA : keysym = 0x6fb
let _Cyrillic_E : keysym = 0x6fc
let _Cyrillic_SHCHA : keysym = 0x6fd
let _Cyrillic_CHE : keysym = 0x6fe
let _Cyrillic_HARDSIGN : keysym = 0x6ff
let _Greek_ALPHAaccent : keysym = 0x7a1
let _Greek_EPSILONaccent : keysym = 0x7a2
let _Greek_ETAaccent : keysym = 0x7a3
let _Greek_IOTAaccent : keysym = 0x7a4
let _Greek_IOTAdiaeresis : keysym = 0x7a5
let _Greek_OMICRONaccent : keysym = 0x7a7
let _Greek_UPSILONaccent : keysym = 0x7a8
let _Greek_UPSILONdieresis : keysym = 0x7a9
let _Greek_OMEGAaccent : keysym = 0x7ab
let _Greek_accentdieresis : keysym = 0x7ae
let _Greek_horizbar : keysym = 0x7af
let _Greek_alphaaccent : keysym = 0x7b1
let _Greek_epsilonaccent : keysym = 0x7b2
let _Greek_etaaccent : keysym = 0x7b3
let _Greek_iotaaccent : keysym = 0x7b4
let _Greek_iotadieresis : keysym = 0x7b5
let _Greek_iotaaccentdieresis : keysym = 0x7b6
let _Greek_omicronaccent : keysym = 0x7b7
let _Greek_upsilonaccent : keysym = 0x7b8
let _Greek_upsilondieresis : keysym = 0x7b9
let _Greek_upsilonaccentdieresis : keysym = 0x7ba
let _Greek_omegaaccent : keysym = 0x7bb
let _Greek_ALPHA : keysym = 0x7c1
let _Greek_BETA : keysym = 0x7c2
let _Greek_GAMMA : keysym = 0x7c3
let _Greek_DELTA : keysym = 0x7c4
let _Greek_EPSILON : keysym = 0x7c5
let _Greek_ZETA : keysym = 0x7c6
let _Greek_ETA : keysym = 0x7c7
let _Greek_THETA : keysym = 0x7c8
let _Greek_IOTA : keysym = 0x7c9
let _Greek_KAPPA : keysym = 0x7ca
let _Greek_LAMDA : keysym = 0x7cb
let _Greek_LAMBDA : keysym = 0x7cb
let _Greek_MU : keysym = 0x7cc
let _Greek_NU : keysym = 0x7cd
let _Greek_XI : keysym = 0x7ce
let _Greek_OMICRON : keysym = 0x7cf
let _Greek_PI : keysym = 0x7d0
let _Greek_RHO : keysym = 0x7d1
let _Greek_SIGMA : keysym = 0x7d2
let _Greek_TAU : keysym = 0x7d4
let _Greek_UPSILON : keysym = 0x7d5
let _Greek_PHI : keysym = 0x7d6
let _Greek_CHI : keysym = 0x7d7
let _Greek_PSI : keysym = 0x7d8
let _Greek_OMEGA : keysym = 0x7d9
let _Greek_alpha : keysym = 0x7e1
let _Greek_beta : keysym = 0x7e2
let _Greek_gamma : keysym = 0x7e3
let _Greek_delta : keysym = 0x7e4
let _Greek_epsilon : keysym = 0x7e5
let _Greek_zeta : keysym = 0x7e6
let _Greek_eta : keysym = 0x7e7
let _Greek_theta : keysym = 0x7e8
let _Greek_iota : keysym = 0x7e9
let _Greek_kappa : keysym = 0x7ea
let _Greek_lamda : keysym = 0x7eb
let _Greek_lambda : keysym = 0x7eb
let _Greek_mu : keysym = 0x7ec
let _Greek_nu : keysym = 0x7ed
let _Greek_xi : keysym = 0x7ee
let _Greek_omicron : keysym = 0x7ef
let _Greek_pi : keysym = 0x7f0
let _Greek_rho : keysym = 0x7f1
let _Greek_sigma : keysym = 0x7f2
let _Greek_finalsmallsigma : keysym = 0x7f3
let _Greek_tau : keysym = 0x7f4
let _Greek_upsilon : keysym = 0x7f5
let _Greek_phi : keysym = 0x7f6
let _Greek_chi : keysym = 0x7f7
let _Greek_psi : keysym = 0x7f8
let _Greek_omega : keysym = 0x7f9
let _Greek_switch : keysym = 0xFF7E
let _leftradical : keysym = 0x8a1
let _topleftradical : keysym = 0x8a2
let _horizconnector : keysym = 0x8a3
let _topintegral : keysym = 0x8a4
let _botintegral : keysym = 0x8a5
let _vertconnector : keysym = 0x8a6
let _topleftsqbracket : keysym = 0x8a7
let _botleftsqbracket : keysym = 0x8a8
let _toprightsqbracket : keysym = 0x8a9
let _botrightsqbracket : keysym = 0x8aa
let _topleftparens : keysym = 0x8ab
let _botleftparens : keysym = 0x8ac
let _toprightparens : keysym = 0x8ad
let _botrightparens : keysym = 0x8ae
let _leftmiddlecurlybrace : keysym = 0x8af
let _rightmiddlecurlybrace : keysym = 0x8b0
let _topleftsummation : keysym = 0x8b1
let _botleftsummation : keysym = 0x8b2
let _topvertsummationconnector : keysym = 0x8b3
let _botvertsummationconnector : keysym = 0x8b4
let _toprightsummation : keysym = 0x8b5
let _botrightsummation : keysym = 0x8b6
let _rightmiddlesummation : keysym = 0x8b7
let _lessthanequal : keysym = 0x8bc
let _notequal : keysym = 0x8bd
let _greaterthanequal : keysym = 0x8be
let _integral : keysym = 0x8bf
let _therefore : keysym = 0x8c0
let _variation : keysym = 0x8c1
let _infinity : keysym = 0x8c2
let _nabla : keysym = 0x8c5
let _approximate : keysym = 0x8c8
let _similarequal : keysym = 0x8c9
let _ifonlyif : keysym = 0x8cd
let _implies : keysym = 0x8ce
let _identical : keysym = 0x8cf
let _radical : keysym = 0x8d6
let _includedin : keysym = 0x8da
let _includes : keysym = 0x8db
let _intersection : keysym = 0x8dc
let _union : keysym = 0x8dd
let _logicaland : keysym = 0x8de
let _logicalor : keysym = 0x8df
let _partialderivative : keysym = 0x8ef
let _function : keysym = 0x8f6
let _leftarrow : keysym = 0x8fb
let _uparrow : keysym = 0x8fc
let _rightarrow : keysym = 0x8fd
let _downarrow : keysym = 0x8fe
let _blank : keysym = 0x9df
let _soliddiamond : keysym = 0x9e0
let _checkerboard : keysym = 0x9e1
let _ht : keysym = 0x9e2
let _ff : keysym = 0x9e3
let _cr : keysym = 0x9e4
let _lf : keysym = 0x9e5
let _nl : keysym = 0x9e8
let _vt : keysym = 0x9e9
let _lowrightcorner : keysym = 0x9ea
let _uprightcorner : keysym = 0x9eb
let _upleftcorner : keysym = 0x9ec
let _lowleftcorner : keysym = 0x9ed
let _crossinglines : keysym = 0x9ee
let _horizlinescan1 : keysym = 0x9ef
let _horizlinescan3 : keysym = 0x9f0
let _horizlinescan5 : keysym = 0x9f1
let _horizlinescan7 : keysym = 0x9f2
let _horizlinescan9 : keysym = 0x9f3
let _leftt : keysym = 0x9f4
let _rightt : keysym = 0x9f5
let _bott : keysym = 0x9f6
let _topt : keysym = 0x9f7
let _vertbar : keysym = 0x9f8
let _emspace : keysym = 0xaa1
let _enspace : keysym = 0xaa2
let _em3space : keysym = 0xaa3
let _em4space : keysym = 0xaa4
let _digitspace : keysym = 0xaa5
let _punctspace : keysym = 0xaa6
let _thinspace : keysym = 0xaa7
let _hairspace : keysym = 0xaa8
let _emdash : keysym = 0xaa9
let _endash : keysym = 0xaaa
let _signifblank : keysym = 0xaac
let _ellipsis : keysym = 0xaae
let _doubbaselinedot : keysym = 0xaaf
let _onethird : keysym = 0xab0
let _twothirds : keysym = 0xab1
let _onefifth : keysym = 0xab2
let _twofifths : keysym = 0xab3
let _threefifths : keysym = 0xab4
let _fourfifths : keysym = 0xab5
let _onesixth : keysym = 0xab6
let _fivesixths : keysym = 0xab7
let _careof : keysym = 0xab8
let _figdash : keysym = 0xabb
let _leftanglebracket : keysym = 0xabc
let _decimalpoint : keysym = 0xabd
let _rightanglebracket : keysym = 0xabe
let _marker : keysym = 0xabf
let _oneeighth : keysym = 0xac3
let _threeeighths : keysym = 0xac4
let _fiveeighths : keysym = 0xac5
let _seveneighths : keysym = 0xac6
let _trademark : keysym = 0xac9
let _signaturemark : keysym = 0xaca
let _trademarkincircle : keysym = 0xacb
let _leftopentriangle : keysym = 0xacc
let _rightopentriangle : keysym = 0xacd
let _emopencircle : keysym = 0xace
let _emopenrectangle : keysym = 0xacf
let _leftsinglequotemark : keysym = 0xad0
let _rightsinglequotemark : keysym = 0xad1
let _leftdoublequotemark : keysym = 0xad2
let _rightdoublequotemark : keysym = 0xad3
let _prescription : keysym = 0xad4
let _minutes : keysym = 0xad6
let _seconds : keysym = 0xad7
let _latincross : keysym = 0xad9
let _hexagram : keysym = 0xada
let _filledrectbullet : keysym = 0xadb
let _filledlefttribullet : keysym = 0xadc
let _filledrighttribullet : keysym = 0xadd
let _emfilledcircle : keysym = 0xade
let _emfilledrect : keysym = 0xadf
let _enopencircbullet : keysym = 0xae0
let _enopensquarebullet : keysym = 0xae1
let _openrectbullet : keysym = 0xae2
let _opentribulletup : keysym = 0xae3
let _opentribulletdown : keysym = 0xae4
let _openstar : keysym = 0xae5
let _enfilledcircbullet : keysym = 0xae6
let _enfilledsqbullet : keysym = 0xae7
let _filledtribulletup : keysym = 0xae8
let _filledtribulletdown : keysym = 0xae9
let _leftpointer : keysym = 0xaea
let _rightpointer : keysym = 0xaeb
let _club : keysym = 0xaec
let _diamond : keysym = 0xaed
let _heart : keysym = 0xaee
let _maltesecross : keysym = 0xaf0
let _dagger : keysym = 0xaf1
let _doubledagger : keysym = 0xaf2
let _checkmark : keysym = 0xaf3
let _ballotcross : keysym = 0xaf4
let _musicalsharp : keysym = 0xaf5
let _musicalflat : keysym = 0xaf6
let _malesymbol : keysym = 0xaf7
let _femalesymbol : keysym = 0xaf8
let _telephone : keysym = 0xaf9
let _telephonerecorder : keysym = 0xafa
let _phonographcopyright : keysym = 0xafb
let _caret : keysym = 0xafc
let _singlelowquotemark : keysym = 0xafd
let _doublelowquotemark : keysym = 0xafe
let _cursor : keysym = 0xaff
let _leftcaret : keysym = 0xba3
let _rightcaret : keysym = 0xba6
let _downcaret : keysym = 0xba8
let _upcaret : keysym = 0xba9
let _overbar : keysym = 0xbc0
let _downtack : keysym = 0xbc2
let _upshoe : keysym = 0xbc3
let _downstile : keysym = 0xbc4
let _underbar : keysym = 0xbc6
let _jot : keysym = 0xbca
let _quad : keysym = 0xbcc
let _uptack : keysym = 0xbce
let _circle : keysym = 0xbcf
let _upstile : keysym = 0xbd3
let _downshoe : keysym = 0xbd6
let _rightshoe : keysym = 0xbd8
let _leftshoe : keysym = 0xbda
let _lefttack : keysym = 0xbdc
let _righttack : keysym = 0xbfc
let _hebrew_doublelowline : keysym = 0xcdf
let _hebrew_aleph : keysym = 0xce0
let _hebrew_bet : keysym = 0xce1
let _hebrew_beth : keysym = 0xce1
let _hebrew_gimel : keysym = 0xce2
let _hebrew_gimmel : keysym = 0xce2
let _hebrew_dalet : keysym = 0xce3
let _hebrew_daleth : keysym = 0xce3
let _hebrew_he : keysym = 0xce4
let _hebrew_waw : keysym = 0xce5
let _hebrew_zain : keysym = 0xce6
let _hebrew_zayin : keysym = 0xce6
let _hebrew_chet : keysym = 0xce7
let _hebrew_het : keysym = 0xce7
let _hebrew_tet : keysym = 0xce8
let _hebrew_teth : keysym = 0xce8
let _hebrew_yod : keysym = 0xce9
let _hebrew_finalkaph : keysym = 0xcea
let _hebrew_kaph : keysym = 0xceb
let _hebrew_lamed : keysym = 0xcec
let _hebrew_finalmem : keysym = 0xced
let _hebrew_mem : keysym = 0xcee
let _hebrew_finalnun : keysym = 0xcef
let _hebrew_nun : keysym = 0xcf0
let _hebrew_samech : keysym = 0xcf1
let _hebrew_samekh : keysym = 0xcf1
let _hebrew_ayin : keysym = 0xcf2
let _hebrew_finalpe : keysym = 0xcf3
let _hebrew_pe : keysym = 0xcf4
let _hebrew_finalzade : keysym = 0xcf5
let _hebrew_finalzadi : keysym = 0xcf5
let _hebrew_zade : keysym = 0xcf6
let _hebrew_zadi : keysym = 0xcf6
let _hebrew_qoph : keysym = 0xcf7
let _hebrew_kuf : keysym = 0xcf7
let _hebrew_resh : keysym = 0xcf8
let _hebrew_shin : keysym = 0xcf9
let _hebrew_taw : keysym = 0xcfa
let _hebrew_taf : keysym = 0xcfa
let _Hebrew_switch : keysym = 0xFF7E
let _Thai_kokai : keysym = 0xda1
let _Thai_khokhai : keysym = 0xda2
let _Thai_khokhuat : keysym = 0xda3
let _Thai_khokhwai : keysym = 0xda4
let _Thai_khokhon : keysym = 0xda5
let _Thai_khorakhang : keysym = 0xda6
let _Thai_ngongu : keysym = 0xda7
let _Thai_chochan : keysym = 0xda8
let _Thai_choching : keysym = 0xda9
let _Thai_chochang : keysym = 0xdaa
let _Thai_soso : keysym = 0xdab
let _Thai_chochoe : keysym = 0xdac
let _Thai_yoying : keysym = 0xdad
let _Thai_dochada : keysym = 0xdae
let _Thai_topatak : keysym = 0xdaf
let _Thai_thothan : keysym = 0xdb0
let _Thai_thonangmontho : keysym = 0xdb1
let _Thai_thophuthao : keysym = 0xdb2
let _Thai_nonen : keysym = 0xdb3
let _Thai_dodek : keysym = 0xdb4
let _Thai_totao : keysym = 0xdb5
let _Thai_thothung : keysym = 0xdb6
let _Thai_thothahan : keysym = 0xdb7
let _Thai_thothong : keysym = 0xdb8
let _Thai_nonu : keysym = 0xdb9
let _Thai_bobaimai : keysym = 0xdba
let _Thai_popla : keysym = 0xdbb
let _Thai_phophung : keysym = 0xdbc
let _Thai_fofa : keysym = 0xdbd
let _Thai_phophan : keysym = 0xdbe
let _Thai_fofan : keysym = 0xdbf
let _Thai_phosamphao : keysym = 0xdc0
let _Thai_moma : keysym = 0xdc1
let _Thai_yoyak : keysym = 0xdc2
let _Thai_rorua : keysym = 0xdc3
let _Thai_ru : keysym = 0xdc4
let _Thai_loling : keysym = 0xdc5
let _Thai_lu : keysym = 0xdc6
let _Thai_wowaen : keysym = 0xdc7
let _Thai_sosala : keysym = 0xdc8
let _Thai_sorusi : keysym = 0xdc9
let _Thai_sosua : keysym = 0xdca
let _Thai_hohip : keysym = 0xdcb
let _Thai_lochula : keysym = 0xdcc
let _Thai_oang : keysym = 0xdcd
let _Thai_honokhuk : keysym = 0xdce
let _Thai_paiyannoi : keysym = 0xdcf
let _Thai_saraa : keysym = 0xdd0
let _Thai_maihanakat : keysym = 0xdd1
let _Thai_saraaa : keysym = 0xdd2
let _Thai_saraam : keysym = 0xdd3
let _Thai_sarai : keysym = 0xdd4
let _Thai_saraii : keysym = 0xdd5
let _Thai_saraue : keysym = 0xdd6
let _Thai_sarauee : keysym = 0xdd7
let _Thai_sarau : keysym = 0xdd8
let _Thai_sarauu : keysym = 0xdd9
let _Thai_phinthu : keysym = 0xdda
let _Thai_maihanakat_maitho : keysym = 0xdde
let _Thai_baht : keysym = 0xddf
let _Thai_sarae : keysym = 0xde0
let _Thai_saraae : keysym = 0xde1
let _Thai_sarao : keysym = 0xde2
let _Thai_saraaimaimuan : keysym = 0xde3
let _Thai_saraaimaimalai : keysym = 0xde4
let _Thai_lakkhangyao : keysym = 0xde5
let _Thai_maiyamok : keysym = 0xde6
let _Thai_maitaikhu : keysym = 0xde7
let _Thai_maiek : keysym = 0xde8
let _Thai_maitho : keysym = 0xde9
let _Thai_maitri : keysym = 0xdea
let _Thai_maichattawa : keysym = 0xdeb
let _Thai_thanthakhat : keysym = 0xdec
let _Thai_nikhahit : keysym = 0xded
let _Thai_leksun : keysym = 0xdf0
let _Thai_leknung : keysym = 0xdf1
let _Thai_leksong : keysym = 0xdf2
let _Thai_leksam : keysym = 0xdf3
let _Thai_leksi : keysym = 0xdf4
let _Thai_lekha : keysym = 0xdf5
let _Thai_lekhok : keysym = 0xdf6
let _Thai_lekchet : keysym = 0xdf7
let _Thai_lekpaet : keysym = 0xdf8
let _Thai_lekkao : keysym = 0xdf9
let _Hangul : keysym = 0xff31
let _Hangul_Start : keysym = 0xff32
let _Hangul_End : keysym = 0xff33
let _Hangul_Hanja : keysym = 0xff34
let _Hangul_Jamo : keysym = 0xff35
let _Hangul_Romaja : keysym = 0xff36
let _Hangul_Codeinput : keysym = 0xff37
let _Hangul_Jeonja : keysym = 0xff38
let _Hangul_Banja : keysym = 0xff39
let _Hangul_PreHanja : keysym = 0xff3a
let _Hangul_PostHanja : keysym = 0xff3b
let _Hangul_SingleCandidate : keysym = 0xff3c
let _Hangul_MultipleCandidate : keysym = 0xff3d
let _Hangul_PreviousCandidate : keysym = 0xff3e
let _Hangul_Special : keysym = 0xff3f
let _Hangul_switch : keysym = 0xFF7E
let _Hangul_Kiyeog : keysym = 0xea1
let _Hangul_SsangKiyeog : keysym = 0xea2
let _Hangul_KiyeogSios : keysym = 0xea3
let _Hangul_Nieun : keysym = 0xea4
let _Hangul_NieunJieuj : keysym = 0xea5
let _Hangul_NieunHieuh : keysym = 0xea6
let _Hangul_Dikeud : keysym = 0xea7
let _Hangul_SsangDikeud : keysym = 0xea8
let _Hangul_Rieul : keysym = 0xea9
let _Hangul_RieulKiyeog : keysym = 0xeaa
let _Hangul_RieulMieum : keysym = 0xeab
let _Hangul_RieulPieub : keysym = 0xeac
let _Hangul_RieulSios : keysym = 0xead
let _Hangul_RieulTieut : keysym = 0xeae
let _Hangul_RieulPhieuf : keysym = 0xeaf
let _Hangul_RieulHieuh : keysym = 0xeb0
let _Hangul_Mieum : keysym = 0xeb1
let _Hangul_Pieub : keysym = 0xeb2
let _Hangul_SsangPieub : keysym = 0xeb3
let _Hangul_PieubSios : keysym = 0xeb4
let _Hangul_Sios : keysym = 0xeb5
let _Hangul_SsangSios : keysym = 0xeb6
let _Hangul_Ieung : keysym = 0xeb7
let _Hangul_Jieuj : keysym = 0xeb8
let _Hangul_SsangJieuj : keysym = 0xeb9
let _Hangul_Cieuc : keysym = 0xeba
let _Hangul_Khieuq : keysym = 0xebb
let _Hangul_Tieut : keysym = 0xebc
let _Hangul_Phieuf : keysym = 0xebd
let _Hangul_Hieuh : keysym = 0xebe
let _Hangul_A : keysym = 0xebf
let _Hangul_AE : keysym = 0xec0
let _Hangul_YA : keysym = 0xec1
let _Hangul_YAE : keysym = 0xec2
let _Hangul_EO : keysym = 0xec3
let _Hangul_E : keysym = 0xec4
let _Hangul_YEO : keysym = 0xec5
let _Hangul_YE : keysym = 0xec6
let _Hangul_O : keysym = 0xec7
let _Hangul_WA : keysym = 0xec8
let _Hangul_WAE : keysym = 0xec9
let _Hangul_OE : keysym = 0xeca
let _Hangul_YO : keysym = 0xecb
let _Hangul_U : keysym = 0xecc
let _Hangul_WEO : keysym = 0xecd
let _Hangul_WE : keysym = 0xece
let _Hangul_WI : keysym = 0xecf
let _Hangul_YU : keysym = 0xed0
let _Hangul_EU : keysym = 0xed1
let _Hangul_YI : keysym = 0xed2
let _Hangul_I : keysym = 0xed3
let _Hangul_J_Kiyeog : keysym = 0xed4
let _Hangul_J_SsangKiyeog : keysym = 0xed5
let _Hangul_J_KiyeogSios : keysym = 0xed6
let _Hangul_J_Nieun : keysym = 0xed7
let _Hangul_J_NieunJieuj : keysym = 0xed8
let _Hangul_J_NieunHieuh : keysym = 0xed9
let _Hangul_J_Dikeud : keysym = 0xeda
let _Hangul_J_Rieul : keysym = 0xedb
let _Hangul_J_RieulKiyeog : keysym = 0xedc
let _Hangul_J_RieulMieum : keysym = 0xedd
let _Hangul_J_RieulPieub : keysym = 0xede
let _Hangul_J_RieulSios : keysym = 0xedf
let _Hangul_J_RieulTieut : keysym = 0xee0
let _Hangul_J_RieulPhieuf : keysym = 0xee1
let _Hangul_J_RieulHieuh : keysym = 0xee2
let _Hangul_J_Mieum : keysym = 0xee3
let _Hangul_J_Pieub : keysym = 0xee4
let _Hangul_J_PieubSios : keysym = 0xee5
let _Hangul_J_Sios : keysym = 0xee6
let _Hangul_J_SsangSios : keysym = 0xee7
let _Hangul_J_Ieung : keysym = 0xee8
let _Hangul_J_Jieuj : keysym = 0xee9
let _Hangul_J_Cieuc : keysym = 0xeea
let _Hangul_J_Khieuq : keysym = 0xeeb
let _Hangul_J_Tieut : keysym = 0xeec
let _Hangul_J_Phieuf : keysym = 0xeed
let _Hangul_J_Hieuh : keysym = 0xeee
let _Hangul_RieulYeorinHieuh : keysym = 0xeef
let _Hangul_SunkyeongeumMieum : keysym = 0xef0
let _Hangul_SunkyeongeumPieub : keysym = 0xef1
let _Hangul_PanSios : keysym = 0xef2
let _Hangul_KkogjiDalrinIeung : keysym = 0xef3
let _Hangul_SunkyeongeumPhieuf : keysym = 0xef4
let _Hangul_YeorinHieuh : keysym = 0xef5
let _Hangul_AraeA : keysym = 0xef6
let _Hangul_AraeAE : keysym = 0xef7
let _Hangul_J_PanSios : keysym = 0xef8
let _Hangul_J_KkogjiDalrinIeung : keysym = 0xef9
let _Hangul_J_YeorinHieuh : keysym = 0xefa
let _Korean_Won : keysym = 0xeff
